elephant.spike\_train\_correlation.cross\_correlation\_histogram
================================================================

.. currentmodule:: elephant.spike_train_correlation

.. autofunction:: cross_correlation_histogram